@@ -1,5 +1,7 @@
 source("helper-diversitree.R")
 
+test_that("bd", {
+
 ## Will be useful to have a function for testing tolerance to within
 ## 1e-7, as that works out to be how accurate most things actually
 ## are.
@@ -73,3 +75,4 @@ expect_that(lik.s.n(p, condition.surv=FALSE), equals(ll))
 expect_that(lik.s.d(p, condition.surv=FALSE), equals(ll, tolerance=1e-6))
 expect_that(lik.s.g(p, condition.surv=FALSE), equals(ll))
 expect_that(lik.s.G(p, condition.surv=FALSE), equals(ll))
+})
